@@ -102,6 +102,23 @@ class IconOptionDict(TypedDict, total=False):
 # IconOptions are.
 @dataclass
 class IconOpts:
+    """Options for rendering an icon.
+
+    Parameters
+    ----------
+    glyph_key : str, optional
+        The key of the glyph to use, e.g. `'fa5s.smile'`, by default `None`
+    scale_factor : float, optional
+        The scale factor to use, by default `None`
+    color : ValidColor, optional
+        The color to use, by default `None`. Colors may be specified as a string,
+        `QColor`, `Qt.GlobalColor`, or a 3 or 4-tuple of integers.
+    opacity : float, optional
+        The opacity to use, by default `None`
+    animation : Animation, optional
+        The animation to use, by default `None`
+    """
+
     glyph_key: Union[str, Unset] = _Unset
     scale_factor: Union[float, Unset] = _Unset
     color: Union[ValidColor, Unset] = _Unset
@@ -418,7 +435,7 @@ class QFontIconStore(QObject):
         If you'd like to later use a fontkey in the form of `key.some-name`, then
         `charmap` must be provided and provide a mapping for all of the glyph names
         to their unicode numbers. If a charmap is not provided, glyphs must be directly
-        accessed with their unicode as something like `key.\uffff`.
+        accessed with their unicode as something like `key.\\uffff`.
 
         Parameters
         ----------
@@ -509,7 +526,7 @@ class QFontIconStore(QObject):
     ) -> None:
         """Sets text on a widget to a specific font & glyph.
 
-        This is an alternative to setting a QIcon with a pixmap.  It may
+        This is an alternative to setting a `QIcon` with a pixmap.  It may
         be easier to combine with dynamic stylesheets.
         """
         setText = getattr(widget, "setText", None)
